import re


DESCRIPTION_RE = re.compile(
    r".*<p class=\"package-snippet__description\">(.+)</p>"
)
ITEM_RE = re.compile(r"<a class=\"package-snippet\".*>")
NAME_RE = re.compile(r"<span class=\"package-snippet__name\">(.+)</span>")
VERSION_RE = re.compile(
    r".*<span class=\"package-snippet__version\">(.+)</span>"
)



import setuptools

from pypisearch import __version__ as version


with open("README.md", "r", encoding="utf-8") as file:
    long_description = file.read()

setuptools.setup(
    name="pypisearch",
    version=version,
    author="Serhii Hidenko",
    author_email="shidenko97@gmail.com",
    description="Replacement of temporarily deprecated pip search command",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/shidenko97/pypisearch",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.8",
)
